@@ -4,6 +4,7 @@ use lib '../lib';
 
 use Moose;
 extends 'JSON::RPC::Dispatcher::App';
+use utf8;
 
 sub sum {
     my ($self, @params) = @_;
@@ -17,7 +18,17 @@ sub ip_address {
     return $plack_request->address;
 }
 
+sub utf8_string {
+    return 'déjà vu';
+}
 
-__PACKAGE__->register_rpc_method_names( 'sum', { name => 'ip_address', options => { with_plack_request => 1 }} );
+sub utf8_decoded_string {
+    my $string = "déjà vu";
+    utf8::decode($string);
+    return $string;
+}
+
+
+__PACKAGE__->register_rpc_method_names( 'utf8_decoded_string', 'utf8_string', 'sum', { name => 'ip_address', options => { with_plack_request => 1 }} );
 
 1;
